@@ -76,7 +76,7 @@ class HTTPRequestActivity(ActivityBase):
         #     k: v for k, v in self.raw_args.items() if k not in self.REQUEST_ARGS
         # }
 
-    def get_info(self, info_args=True, expanded_args=None):
+    def get_info(self, info_args=True, expanded_args=None, session=None):
         args_dict = expanded_args if expanded_args else self.raw_args
         url = args_dict.get("url")
         params = args_dict.get("params") or ""
@@ -142,7 +142,7 @@ class HTTPRequestActivity(ActivityBase):
             raise ActivityError(
                 "Missing context variable 'base_url' to resolve relative URLs"
             )
-        expanded_args.setdefault("timeout", session.get_context("timeout"))
+        expanded_args.setdefault("timeout", session.get_context("request_timeout"))
         assert "timeout" in expanded_args
         debug = expanded_args.get("debug")
 
@@ -280,14 +280,15 @@ class DeleteRequestActivity(HTTPRequestActivity):
 
 
 class StaticRequestsActivity(ActivityBase):
+    """
+    This activity recieves a list of URLs (JavaScript, Html, CSS, Images, ...)
+    and loads them, using max. ~5 threads, as a browser would.
+    """
+
     REQUEST_ARGS = {"auth", "data", "json", "headers", "params", "timeout", "verify"}
     _mandatory_args = {"url_list"}
     _known_args = REQUEST_ARGS | _mandatory_args | {"assert_status", "thread_count"}
     _info_args = ("name", "method", "thread_count")
-    """
-    TODO: this activity recieves a list of URLs (JavaScript, Html, CSS, Images, ...)
-    and loads them, using max. ~5 threads, as a browser would.
-    """
 
     def __init__(self, config_manager, **activity_args):
         super().__init__(config_manager, **activity_args)
@@ -297,7 +298,7 @@ class StaticRequestsActivity(ActivityBase):
         """
         url_list = expanded_args.pop("url_list")
         base_url = session.get_context("base_url")
-        expanded_args.setdefault("timeout", session.get_context("timeout"))
+        expanded_args.setdefault("timeout", session.get_context("request_timeout"))
         debug = expanded_args.get("debug")
         thread_count = int(expanded_args.get("thread_count", 1))
         method = "GET"
