@@ -67,8 +67,8 @@ class SessionManager:
     Run a scenario in a single session.
     """
 
-    #: (float)
-    DEFAULT_TIMEOUT = 10.0
+    # #: (float)
+    # DEFAULT_REQUEST_TIMEOUT = 10.0
 
     def __init__(self, run_manager, context, session_id, user):
         # check_arg(run_manager, RunManager)
@@ -90,6 +90,10 @@ class SessionManager:
         self.user = user or User("anonymous", "")
         #: (dict) Copy of `run_config.sessions` configuration
         self.sessions = run_manager.config_manager.sessions.copy()
+        #: (dict) Activities can store per-session data here.
+        #: Note that the activity objects are instintiated only once and shared
+        #: by all sessions.
+        self.data = {}
         #: (bool) True: only simulate activities
         self.dry_run = bool(context.get("dry_run"))
         #: (int) Verbosity 0..5
@@ -98,7 +102,7 @@ class SessionManager:
         self.stop_request = run_manager.stop_request
 
         # Set some default entries in context dict
-        context.setdefault("timeout", self.DEFAULT_TIMEOUT)
+        # context.setdefault("timeout", self.DEFAULT_REQUEST_TIMEOUT)
         context.setdefault("session_id", self.session_id)
         context.setdefault("user", self.user)
 
@@ -317,23 +321,30 @@ class SessionManager:
         self.stats.report_start(self, seq_name, None)
         start_sequence = time.monotonic()
         for act_idx, activity_args in enumerate(sequence, 1):
+            # activity_args["activity"] is an instance of ActivityBase that
+            # we want to re-use it for every session.
+            # The rest of activity_args is copied, so session data is separated
+            activity = activity_args["activity"]
             activity_args = deepcopy(activity_args)
-            activity = activity_args.pop("activity")
+            activity_args.pop("activity")
 
             # Add activity info to path
-            # Note: `get_info()` is not as detailed as it could b, since we don't
+            # Note: `get_info()` is not as detailed as it could, since we don't
             # pass the expanded args here. We set it anyway, so we have a valid
             # stack in case `_evaluate_macros()` blows.
-            with stack.enter("#{:02}-{}".format(act_idx, activity.get_info())):
-
+            with stack.enter(
+                "#{:02}-{}".format(act_idx, activity.get_info(session=self))
+            ):
                 expanded_args = self._evaluate_macros(activity_args, context)
 
                 # Let activity do internal calculations, that might be used by
                 # the follwing call to `get_info()`
-                activity.prepare_execute(self, **expanded_args)
+                activity.prepare_execute(self, expanded_args)
 
                 # Enhance the path info with expanded args
-                stack.set_last_part(activity.get_info(expanded_args=expanded_args))
+                stack.set_last_part(
+                    activity.get_info(expanded_args=expanded_args, session=self)
+                )
 
                 error = None
                 result = None
@@ -405,7 +416,7 @@ class SessionManager:
         sequences = config_manager.sequences
         scenario = config_manager.scenario
         sessions = config_manager.sessions
-        session_duration = float(sessions.get("duration", 0))
+        session_duration = float(sessions.get("duration", 0.0))
 
         self.publish("start_session", session=self)
         self.stats.report_start(self, None, None)
@@ -422,7 +433,7 @@ class SessionManager:
 
             sequence = sequences.get(seq_name)
             loop_repeat = int(seq_def.get("repeat", 0))
-            loop_duration = float(seq_def.get("duration", 0))
+            loop_duration = float(seq_def.get("duration", 0.0))
             start_seq_loop = time.monotonic()
             loop_idx = 0
             while True:
