@@ -144,6 +144,18 @@ def timetag(seconds=True, ms=False):
     return s
 
 
+def check_cli_verbose(default=3):
+    """Check for presence of `--verbose`/`--quiet` or `-v`/`-q` without using argparse."""
+    args = sys.argv[1:]
+    verbose = default + args.count("--verbose") - args.count("--quiet")
+
+    for arg in args:
+        if arg.startswith("-") and not arg.startswith("--"):
+            verbose += arg[1:].count("v")
+            verbose -= arg[1:].count("q")
+    return verbose
+
+
 def init_logging(verbose=3, path=None):
     """CLI calls this."""
     if verbose < 1:
@@ -390,6 +402,46 @@ def get_dict_attr(d, key_path, default=NO_DEFAULT):
     return value
 
 
+def coerce_str(s):
+    """Return `s` converted to float, int, or str."""
+    check_arg(s, str, or_none=True)
+    if s is None:
+        return None
+    for t in (int, float, str):  # order matters!
+        try:
+            return t(s)
+        except ValueError:
+            if t is str:
+                raise
+
+
+def parse_option_args(opt_list, coerce_values=True):
+    """Evaluate `--option` args.
+
+    Args:
+        opt_list (list):
+            List of option definitions of the form "OPT_NAME:OPT_VALUE"
+        coerce_values (bool=true):
+    Returns:
+        Dict of {opt_name: opt_value, ...}
+    """
+    check_arg(opt_list, list, or_none=True)
+    res = {}
+    if not opt_list:
+        return res
+    for opt in opt_list:
+        # print(opt_list, opt)
+        if ":" not in opt:
+            raise ValueError("Expected 'NAME:VALUE', got {!r}".format(opt))
+        config_name, config_val = opt.split(":", 1)
+        if coerce_values:
+            res[config_name.strip()] = coerce_str(config_val)
+        else:
+            res[config_name.strip()] = config_val
+    # print(opt_list, res)
+    return res
+
+
 def parse_args_from_str(arg_str, arg_defs):  # , context=None):
     """
     Args:
@@ -607,7 +659,10 @@ def format_elap(seconds, count=None, unit="items", high_prec=False):
             res = "{:d}:{:02d} min".format(int(m), int(s))
     else:
         if high_prec:
-            res = "{:.3f} sec".format(seconds)
+            if seconds > 0.01:
+                res = "{:.3f} sec".format(seconds)
+            else:
+                res = "{:f} sec".format(seconds)
         elif seconds > 5:
             res = "{:.1f} sec".format(seconds)
         else:
@@ -623,6 +678,25 @@ def format_elap(seconds, count=None, unit="items", high_prec=False):
     return res
 
 
+def format_num(num):
+    """Return num rounded to reasonable precision (promille)."""
+    if num >= 1000.0:
+        res = "{:,}".format(round(num))
+    elif num >= 100.0:
+        res = str(round(num, 1))
+        # res = "{:,.1f}".format(num)
+    elif num >= 10.0:
+        res = str(round(num, 2))
+        # res = "{:,.2f}".format(num)
+    elif num >= 1.0:
+        res = str(round(num, 3))
+        # res = "{:,.3f}".format(num)
+    else:
+        res = str(num)
+        # res = "{:,}".format(num)
+    return res
+
+
 def format_rate(count, time, unit=None, high_prec=False):
     """Return count / time with reasonable precision."""
     if not time or not count:
